@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 
-from dateutil import parser
-from math import ceil
+"""Module anitya.admin"""
 import logging
+from math import ceil
 
 import flask
+from dateutil import parser
+from sqlalchemy.orm.exc import NoResultFound
 
-from anitya.lib import utilities
-from anitya.db import models, Session
 import anitya
 import anitya.forms
-
+from anitya.db import Session, models
+from anitya.lib import utilities
 from anitya.ui import login_required, ui_blueprint
 
-
 _log = logging.getLogger(__name__)
 
 
@@ -24,12 +24,13 @@ def is_admin(user=None):
     user = user or flask.g.user
     if user.is_authenticated:
         return user.is_admin
+    return False
 
 
 @ui_blueprint.route("/distro/<distro_name>/edit", methods=["GET", "POST"])
 @login_required
 def edit_distro(distro_name):
-
+    """Edit distribution"""
     distro = models.Distro.by_name(Session, distro_name)
     if not distro:
         flask.abort(404)
@@ -89,7 +90,7 @@ def delete_distro(distro_name):
 
         Session.delete(distro)
         Session.commit()
-        flask.flash("Distro %s has been removed" % distro_name)
+        flask.flash(f"Distro {distro_name} has been removed")
         return flask.redirect(flask.url_for("anitya_ui.distros"))
 
     return flask.render_template(
@@ -100,7 +101,7 @@ def delete_distro(distro_name):
 @ui_blueprint.route("/project/<project_id>/delete", methods=["GET", "POST"])
 @login_required
 def delete_project(project_id):
-
+    """Delete project"""
     project = models.Project.get(Session, project_id)
     if not project:
         flask.abort(404)
@@ -126,7 +127,7 @@ def delete_project(project_id):
 
             Session.delete(project)
             Session.commit()
-            flask.flash("Project %s has been removed" % project_name)
+            flask.flash(f"Project {project_name} has been removed")
             return flask.redirect(flask.url_for("anitya_ui.projects"))
         else:
             return flask.redirect(
@@ -143,7 +144,7 @@ def delete_project(project_id):
 )
 @login_required
 def set_project_archive_state(project_id, state):
-
+    """Set project archive state"""
     if not is_admin():
         flask.abort(401)
 
@@ -183,11 +184,9 @@ def set_project_archive_state(project_id, state):
                     user_id=flask.g.user.username,
                 )
                 if bool(archive):
-                    flask.flash("Project '{0}' archived".format(project.name))
+                    flask.flash(f"Project '{project.name}' archived")
                 else:
-                    flask.flash(
-                        "Project '{0}' is no longer archived".format(project.name)
-                    )
+                    flask.flash(f"Project '{project.name}' is no longer archived")
             except anitya.lib.exceptions.AnityaException as err:
                 flask.flash(str(err), "errors")
 
@@ -203,11 +202,12 @@ def set_project_archive_state(project_id, state):
 
 
 @ui_blueprint.route(
-    "/project/<project_id>/delete/<distro_name>/<pkg_name>", methods=["GET", "POST"]
+    "/project/<project_id>/delete/<distro_name>/<path:pkg_name>",
+    methods=["GET", "POST"],
 )
 @login_required
 def delete_project_mapping(project_id, distro_name, pkg_name):
-
+    """Delete project mapping"""
     project = models.Project.get(Session, project_id)
     if not project:
         flask.abort(404)
@@ -241,7 +241,7 @@ def delete_project_mapping(project_id, distro_name, pkg_name):
             Session.delete(package)
             Session.commit()
 
-            flask.flash("Mapping for %s has been removed" % project.name)
+            flask.flash(f"Mapping for {project.name} has been removed")
         return flask.redirect(flask.url_for("anitya_ui.project", project_id=project.id))
 
     return flask.render_template(
@@ -256,7 +256,7 @@ def delete_project_mapping(project_id, distro_name, pkg_name):
 @ui_blueprint.route("/project/<project_id>/delete/<version>", methods=["GET", "POST"])
 @login_required
 def delete_project_version(project_id, version):
-
+    """Delect project version"""
     project = models.Project.get(Session, project_id)
     if not project:
         flask.abort(404)
@@ -268,9 +268,7 @@ def delete_project_version(project_id, version):
             break
 
     if version_obj is None:
-        flask.abort(
-            404, "Version %s not found for project %s" % (version, project.name)
-        )
+        flask.abort(404, f"Version {version} not found for project {project.name}")
 
     if not is_admin():
         flask.abort(401)
@@ -282,9 +280,11 @@ def delete_project_version(project_id, version):
         if confirm:
             utilities.publish_message(
                 project=project.__json__(),
-                topic="project.version.remove",
+                topic="project.version.remove.v2",
                 message=dict(
-                    agent=flask.g.user.username, project=project.name, version=version
+                    agent=flask.g.user.username,
+                    project=project.name,
+                    versions=[version],
                 ),
             )
 
@@ -300,7 +300,7 @@ def delete_project_version(project_id, version):
                 Session.add(project)
             Session.commit()
 
-            flask.flash("Version for %s has been removed" % version)
+            flask.flash(f"Version for {version} has been removed")
         return flask.redirect(flask.url_for("anitya_ui.project", project_id=project.id))
 
     return flask.render_template(
@@ -331,21 +331,25 @@ def delete_project_versions(project_id):
 
     if form.validate_on_submit():
         if confirm:
-            for version in project.versions_obj:
-                # Delete the record of the version for this project
-                Session.delete(version)
+            versions = []
 
-                utilities.publish_message(
-                    project=project.__json__(),
-                    topic="project.version.remove",
-                    message=dict(
-                        agent=flask.g.user.username,
-                        project=project.name,
-                        version=str(version),
-                    ),
-                )
+            # Delete the versions on this project
+            for version in project.versions_obj:
+                Session.delete(version)
+                versions.append(str(version))
 
             project.latest_version = None
+
+            utilities.publish_message(
+                project=project.__json__(),
+                topic="project.version.remove.v2",
+                message=dict(
+                    agent=flask.g.user.username,
+                    project=project.name,
+                    versions=versions,
+                ),
+            )
+
             Session.add(project)
             Session.commit()
 
@@ -363,7 +367,7 @@ def delete_project_versions(project_id):
 @ui_blueprint.route("/flags")
 @login_required
 def browse_flags():
-
+    """Brows flags"""
     if not is_admin():
         flask.abort(401)
 
@@ -448,7 +452,7 @@ def browse_flags():
 @ui_blueprint.route("/flags/<flag_id>/set/<state>", methods=["POST"])
 @login_required
 def set_flag_state(flag_id, state):
-
+    """Set flag state"""
     if not is_admin():
         flask.abort(401)
 
@@ -467,7 +471,7 @@ def set_flag_state(flag_id, state):
             utilities.set_flag_state(
                 Session, flag=flag, state=state, user_id=flask.g.user.username
             )
-            flask.flash("Flag {0} set to {1}".format(flag.id, state))
+            flask.flash(f"Flag {flag.id} set to {state}")
         except anitya.lib.exceptions.AnityaException as err:
             flask.flash(str(err), "errors")
 
@@ -477,7 +481,7 @@ def set_flag_state(flag_id, state):
 @ui_blueprint.route("/users", methods=["GET"])
 @login_required
 def browse_users():
-
+    """Browse users"""
     if not is_admin():
         flask.abort(401)
 
@@ -577,7 +581,7 @@ def browse_users():
 @ui_blueprint.route("/users/<user_id>/admin/<state>", methods=["POST"])
 @login_required
 def set_user_admin_state(user_id, state):
-
+    """Set user admin state"""
     if not is_admin():
         flask.abort(401)
 
@@ -605,9 +609,9 @@ def set_user_admin_state(user_id, state):
             Session.add(user)
             Session.commit()
             if state:
-                flask.flash("User {0} is now admin".format(user.username))
+                flask.flash(f"User {user.username} is now admin")
             else:
-                flask.flash("User {0} is not admin anymore".format(user.username))
+                flask.flash(f"User {user.username} is not admin anymore")
         except Exception as err:
             _log.exception(err)
             flask.flash(str(err), "errors")
@@ -619,7 +623,7 @@ def set_user_admin_state(user_id, state):
 @ui_blueprint.route("/users/<user_id>/active/<state>", methods=["POST"])
 @login_required
 def set_user_active_state(user_id, state):
-
+    """Set user active state"""
     if not is_admin():
         flask.abort(401)
 
@@ -647,12 +651,37 @@ def set_user_active_state(user_id, state):
             Session.add(user)
             Session.commit()
             if state:
-                flask.flash("User {0} is no longer banned".format(user.username))
+                flask.flash(f"User {user.username} is no longer banned")
             else:
-                flask.flash("User {0} is banned".format(user.username))
+                flask.flash(f"User {user.username} is banned")
         except Exception as err:
             _log.exception(err)
             flask.flash(str(err), "errors")
             Session.rollback()
 
     return flask.redirect(flask.url_for("anitya_ui.browse_users"))
+
+
+@ui_blueprint.route("/users/<user_id>/delete", methods=["GET", "POST"])
+@login_required
+def delete_user(user_id):
+    """Delete user"""
+    try:
+        user = Session.query(models.User).filter(models.User.id == user_id).one()
+    except NoResultFound:
+        flask.abort(404)
+
+    user_name = user.username
+    form = anitya.forms.ConfirmationForm()
+    confirm = flask.request.form.get("confirm", False)
+
+    if form.validate_on_submit():
+        if confirm:
+            Session.delete(user)
+            Session.commit()
+            flask.flash(f"User {user_name} has been removed", "success")
+            return flask.redirect(flask.url_for("anitya_ui.browse_users"))
+
+    return flask.render_template(
+        "user_delete.html", current="users", user=user, form=form
+    )
