@@ -8,18 +8,18 @@ It uses OpenID Connect for endpoints that require authentication.
 import logging
 
 import flask_login
-from flask import jsonify, request, abort, make_response
+from flask import abort, jsonify, make_response, request
 from flask.views import MethodView
 from sqlalchemy import func
 from sqlalchemy.exc import IntegrityError
 from sqlalchemy.orm.exc import NoResultFound
-from webargs import fields, ValidationError
+from webargs import ValidationError, fields
 from webargs.flaskparser import FlaskParser
 
 from anitya import authentication
 from anitya.db import Session, models
 from anitya.lib import utilities
-from anitya.lib.exceptions import ProjectExists, AnityaException
+from anitya.lib.exceptions import AnityaException, ProjectExists
 
 _log = logging.getLogger(__name__)
 
@@ -125,7 +125,8 @@ class PackagesResource(MethodView):
                         "name": "python-requests"
                         "project": "requests",
                         "ecosystem": "pypi",
-                        "version": "2.28.1"
+                        "version": "2.28.1",
+                        "stable_version": "2.28.1"
                     }
                 ],
                 "items_per_page": 25,
@@ -144,9 +145,9 @@ class PackagesResource(MethodView):
         :statuscode 400: If one or more of the query arguments is invalid.
         """
         user_args = {
-            "page": fields.Int(validate=_page_validator, missing=1),
+            "page": fields.Int(validate=_page_validator, load_default=1),
             "items_per_page": fields.Int(
-                validate=_items_per_page_validator, missing=25
+                validate=_items_per_page_validator, load_default=25
             ),
             "distribution": fields.Str(),
             "name": fields.Str(),
@@ -168,6 +169,7 @@ class PackagesResource(MethodView):
                     "project": package.project.name,
                     "ecosystem": package.project.ecosystem_name,
                     "version": package.project.latest_version,
+                    "stable_version": package.project.latest_stable_version,
                 }
                 for package in page.items
             ],
@@ -218,11 +220,13 @@ class PackagesResource(MethodView):
 
         :reqheader Authorization: API token to use for authentication
         :reqjson string distribution: The name of the distribution that contains this
-            package.
-        :reqjson string package_name: The name of the package in the distribution repository.
-        :reqjson string project_name: The project name in Anitya.
+            package. (mandatory argument)
+        :reqjson string package_name: The name of the package in the distribution
+            repository. (mandatory argument)
+        :reqjson string project_name: The project name in Anitya. (mandatory argument)
         :reqjson string project_ecosystem: The ecosystem the project is a part of.
-            If it's not part of an ecosystem, use the homepage used in the Anitya project.
+            If it's not part of an ecosystem, use the homepage used in the Anitya
+            project. (mandatory argument)
 
         :statuscode 201: When the package was successfully created.
         :statuscode 400: When required arguments are missing or malformed.
@@ -239,18 +243,16 @@ class PackagesResource(MethodView):
             args = parser.parse(user_args, request, location="form")
         else:
             args = parser.parse(user_args, request, location="json")
-        try:
-            project = models.Project.query.filter(
-                func.lower(models.Project.name) == func.lower(args["project_name"]),
-                func.lower(models.Project.ecosystem_name)
-                == func.lower(args["project_ecosystem"]),
-            ).one()
-        except NoResultFound:
+        project = models.Project.query.filter(
+            func.lower(models.Project.name) == func.lower(args["project_name"]),
+            func.lower(models.Project.ecosystem_name)
+            == func.lower(args["project_ecosystem"]),
+        ).first()
+        if not project:
             return (
                 {
-                    "error": 'Project "{}" in ecosystem "{}" not found'.format(
-                        args["project_name"], args["project_ecosystem"]
-                    )
+                    "error": f'Project "{args["project_name"]}" in ecosystem '
+                    f'"{args["project_ecosystem"]}" not found'
                 },
                 400,
             )
@@ -261,7 +263,7 @@ class PackagesResource(MethodView):
             ).one()
         except NoResultFound:
             return (
-                {"error": 'Distribution "{}" not found'.format(args["distribution"])},
+                {"error": f"Distribution \"{args['distribution']}\" not found"},
                 400,
             )
 
@@ -373,9 +375,9 @@ class ProjectsResource(MethodView):
         :statuscode 400: If one or more of the query arguments is invalid.
         """
         user_args = {
-            "page": fields.Int(validate=_page_validator, missing=1),
+            "page": fields.Int(validate=_page_validator, load_default=1),
             "items_per_page": fields.Int(
-                validate=_items_per_page_validator, missing=25
+                validate=_items_per_page_validator, load_default=25
             ),
             "ecosystem": fields.Str(),
             "name": fields.Str(),
@@ -447,9 +449,9 @@ class ProjectsResource(MethodView):
             }
 
         :query string access_token: Your API access token.
-        :reqjson string name: The project name
-        :reqjson string homepage: The project homepage URL
-        :reqjson string backend: The project backend (github, folder, etc.).
+        :reqjson string name: The project name (mandatory argument)
+        :reqjson string homepage: The project homepage URL (mandatory argument)
+        :reqjson string backend: The project backend (github, folder, etc.). (mandatory argument)
         :reqjson string version_url: The URL to fetch when determining the
                                      project version (defaults to null).
         :reqjson string version_scheme: The project version scheme. If missing, it's set to "RPM".
@@ -477,15 +479,15 @@ class ProjectsResource(MethodView):
             "name": fields.Str(required=True),
             "homepage": fields.Str(required=True),
             "backend": fields.Str(required=True),
-            "version_url": fields.Str(missing=None),
-            "version_scheme": fields.Str(missing="RPM"),
-            "version_pattern": fields.Str(missing=None),
-            "version_prefix": fields.Str(missing=None),
-            "pre_release_filter": fields.Str(missing=None),
-            "version_filter": fields.Str(missing=None),
-            "regex": fields.Str(missing=None),
-            "insecure": fields.Bool(missing=False),
-            "check_release": fields.Bool(missing=False),
+            "version_url": fields.Str(load_default=None),
+            "version_scheme": fields.Str(load_default="RPM"),
+            "version_pattern": fields.Str(load_default=None),
+            "version_prefix": fields.Str(load_default=None),
+            "pre_release_filter": fields.Str(load_default=None),
+            "version_filter": fields.Str(load_default=None),
+            "regex": fields.Str(load_default=None),
+            "insecure": fields.Bool(load_default=False),
+            "check_release": fields.Bool(load_default=False),
         }
         if not request.is_json:
             args = parser.parse(user_args, request, location="form")
@@ -691,10 +693,10 @@ class VersionsResource(MethodView):
             "version_prefix": fields.Str(),
             "pre_release_filter": fields.Str(),
             "version_filter": fields.Str(),
-            "regex": fields.Str(missing=None),
-            "insecure": fields.Bool(missing=False),
-            "releases_only": fields.Bool(missing=False),
-            "dry_run": fields.Bool(missing=True),
+            "regex": fields.Str(load_default=None),
+            "insecure": fields.Bool(load_default=False),
+            "releases_only": fields.Bool(load_default=False),
+            "dry_run": fields.Bool(load_default=True),
         }
         if not request.is_json:
             args = parser.parse(user_args, request, location="form")
