@@ -5,10 +5,9 @@ Revises: b13662e5d288
 Create Date: 2018-12-07 08:58:45.152649
 """
 
-from alembic import op
-import sqlalchemy as sa
 import arrow
-
+import sqlalchemy as sa
+from alembic import op
 
 # revision identifiers, used by Alembic.
 revision = "1bf8aead6179"
@@ -23,7 +22,7 @@ def upgrade():
             "last_check",
             sa.TIMESTAMP(timezone=True),
             default=arrow.utcnow().datetime,
-            server_default=sa.func.current_timestamp(),
+            server_default=sa.sql.functions.current_timestamp(),
         ),
     )
 
@@ -33,7 +32,7 @@ def upgrade():
             "next_check",
             sa.TIMESTAMP(timezone=True),
             default=arrow.utcnow().datetime,
-            server_default=sa.func.current_timestamp(),
+            server_default=sa.sql.functions.current_timestamp(),
         ),
     )
     op.create_index(
