@@ -19,26 +19,26 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 """SQLAlchemy database models."""
 
-from secrets import choice as random_choice
 import datetime
-import arrow
 import logging
-import time
 import string
+import time
 import uuid
+from secrets import choice as random_choice
 
+import arrow
 import six
 import sqlalchemy as sa
 from sqlalchemy.dialects.postgresql import UUID
 from sqlalchemy.orm import validates
 from sqlalchemy.orm.exc import NoResultFound
-from sqlalchemy.types import TypeDecorator, CHAR
+from sqlalchemy.types import CHAR, TypeDecorator
 
 from anitya.config import config as anitya_config
+from anitya.lib.plugins import BACKEND_PLUGINS, ECOSYSTEM_PLUGINS, VERSION_PLUGINS
 from anitya.lib.versions import GLOBAL_DEFAULT as DEFAULT_VERSION_SCHEME
-from anitya.lib.plugins import ECOSYSTEM_PLUGINS, BACKEND_PLUGINS, VERSION_PLUGINS
-from .meta import Base
 
+from .meta import Base
 
 _log = logging.getLogger(__name__)
 
@@ -62,6 +62,8 @@ def _paginate_query(query, page):
 
 
 class Distro(Base):
+    """Class Distro"""
+
     __tablename__ = "distros"
 
     name = sa.Column(sa.String(200), primary_key=True)
@@ -75,6 +77,7 @@ class Distro(Base):
 
     @classmethod
     def by_name(cls, session, name):
+        """Get Distro name"""
         query = session.query(cls).filter(
             sa.func.lower(cls.name) == sa.func.lower(name)
         )
@@ -85,6 +88,7 @@ class Distro(Base):
 
     @classmethod
     def all(cls, session, page=None, count=False):
+        """Distro all"""
         query = session.query(cls).order_by(cls.name)
 
         query = _paginate_query(query, page)
@@ -117,6 +121,7 @@ class Distro(Base):
 
     @classmethod
     def get_or_create(cls, session, name):
+        """Get distro or create it"""
         distro = cls.by_name(session, name)
         if not distro:
             distro = cls(name=name)
@@ -126,6 +131,8 @@ class Distro(Base):
 
 
 class Packages(Base):
+    """Class Packages"""
+
     __tablename__ = "packages"
 
     id = sa.Column(sa.Integer, primary_key=True)
@@ -150,21 +157,19 @@ class Packages(Base):
     )
 
     def __repr__(self):
-        return "<Packages(%s, %s: %s)>" % (
-            self.project_id,
-            self.distro_name,
-            self.package_name,
-        )
+        return f"<Packages({self.project_id}, {self.distro_name}: {self.package_name})>"
 
     def __json__(self):
         return dict(package_name=self.package_name, distro=self.distro_name)
 
     @classmethod
     def by_id(cls, session, pkg_id):
+        """Packages by id"""
         return session.query(cls).filter_by(id=pkg_id).first()
 
     @classmethod
     def get(cls, session, project_id, distro_name, package_name):
+        """Get Packages"""
         query = (
             session.query(cls)
             .filter(cls.project_id == project_id)
@@ -175,6 +180,7 @@ class Packages(Base):
 
     @classmethod
     def by_package_name_distro(cls, session, package_name, distro_name):
+        """Get package by package name distro"""
         query = (
             session.query(cls)
             .filter(cls.package_name == package_name)
@@ -264,7 +270,9 @@ class Project(Base):
     )
 
     updated_on = sa.Column(
-        sa.DateTime, server_default=sa.func.now(), onupdate=sa.func.current_timestamp()
+        sa.DateTime,
+        server_default=sa.sql.functions.now(),
+        onupdate=sa.sql.functions.current_timestamp(),
     )
     created_on = sa.Column(sa.DateTime, default=datetime.datetime.utcnow)
 
@@ -279,8 +287,9 @@ class Project(Base):
 
     @validates("backend")
     def validate_backend(self, key, value):
+        """Validate backend"""
         if value not in BACKEND_PLUGINS.get_plugin_names():
-            raise ValueError('Backend "{}" is not supported.'.format(value))
+            raise ValueError(f"Backend '{value}' is not supported.")
         return value
 
     @property
@@ -304,6 +313,19 @@ class Project(Base):
         sorted_versions = self.get_sorted_version_objects()
         return [version for version in sorted_versions if not version.prerelease()]
 
+    @property
+    def latest_stable_version(self):
+        """
+        Return latest stable version.
+
+        Returns:
+           `string`: Latest stable version if exists, otherwise None.
+        """
+        stable_versions = self.stable_versions
+        if stable_versions:
+            return str(stable_versions[0])
+        return None
+
     def get_last_created_version(self):
         """
         Returns last obtained release by date.
@@ -406,6 +428,7 @@ class Project(Base):
 
     @property
     def latest_version_object(self):
+        """Latest version object"""
         sorted_versions = self.get_sorted_version_objects()
         if sorted_versions:
             return sorted_versions[0]
@@ -444,7 +467,7 @@ class Project(Base):
         return VERSION_PLUGINS.get_plugin(version_scheme)
 
     def __repr__(self):
-        return "<Project(%s, %s)>" % (self.name, self.homepage)
+        return f"<Project({self.name}, {self.homepage})>"
 
     def __json__(self, detailed=False):
         output = dict(
@@ -457,12 +480,12 @@ class Project(Base):
             version=self.latest_version,
             versions=self.versions,
             stable_versions=[str(v) for v in self.stable_versions],
-            created_on=time.mktime(self.created_on.timetuple())
-            if self.created_on
-            else None,
-            updated_on=time.mktime(self.updated_on.timetuple())
-            if self.updated_on
-            else None,
+            created_on=(
+                time.mktime(self.created_on.timetuple()) if self.created_on else None
+            ),
+            updated_on=(
+                time.mktime(self.updated_on.timetuple()) if self.updated_on else None
+            ),
             ecosystem=self.ecosystem_name,
         )
         if detailed:
@@ -472,6 +495,7 @@ class Project(Base):
 
     @classmethod
     def get_or_create(cls, session, name, homepage, backend="custom"):
+        """Get or Create"""
         project = cls.by_name_and_homepage(session, name, homepage)
         if not project:
             project = cls(name=name, homepage=homepage, backend=backend)
@@ -481,20 +505,24 @@ class Project(Base):
 
     @classmethod
     def by_name(cls, session, name):
+        """By name"""
         return session.query(cls).filter_by(name=name).all()
 
     @classmethod
     def by_id(cls, session, project_id):
+        """By id"""
         return session.query(cls).filter_by(id=project_id).first()
 
     get = by_id
 
     @classmethod
     def by_homepage(cls, session, homepage):
+        """By homepage"""
         return session.query(cls).filter_by(homepage=homepage).all()
 
     @classmethod
     def by_name_and_homepage(cls, session, name, homepage):
+        """By  name and homepage"""
         query = (
             session.query(cls).filter(cls.name == name).filter(cls.homepage == homepage)
         )
@@ -502,6 +530,7 @@ class Project(Base):
 
     @classmethod
     def by_name_and_ecosystem(cls, session, name, ecosystem):
+        """By name and ecosystem"""
         try:
             query = session.query(cls)
             query = query.filter(cls.name == name, cls.ecosystem_name == ecosystem)
@@ -511,6 +540,7 @@ class Project(Base):
 
     @classmethod
     def all(cls, session, page=None, count=False):
+        """all"""
         query = session.query(Project).order_by(sa.func.lower(Project.name))
 
         query = _paginate_query(query, page)
@@ -522,6 +552,7 @@ class Project(Base):
 
     @classmethod
     def by_distro(cls, session, distro, page=None, count=False):
+        """By distro"""
         query = (
             session.query(Project)
             .filter(Project.id == Packages.project_id)
@@ -641,6 +672,24 @@ class Project(Base):
         else:
             return query.all()
 
+    @classmethod
+    def sort_projects(cls, projects, sort):
+        """
+        Sorts a list of projects objects based on a sort parameter.
+        """
+        sort_attr, _, sort_order = sort.partition("_")
+
+        attr_map = {"name": "name", "homepage": "homepage", "backend": "backend"}
+
+        sort_by = attr_map.get(sort_attr, "name")
+
+        projects.sort(
+            key=lambda project: getattr(project, sort_by, "").lower(),
+            reverse=sort_order == "desc",
+        )
+
+        return projects
+
 
 class ProjectVersion(Base):
     """
@@ -691,6 +740,8 @@ class ProjectVersion(Base):
 
 
 class ProjectFlag(Base):
+    """Class ProjectFlag"""
+
     __tablename__ = "projects_flags"
 
     id = sa.Column(sa.Integer, primary_key=True)
@@ -704,7 +755,9 @@ class ProjectFlag(Base):
     state = sa.Column(sa.String(50), default="open", nullable=False)
     created_on = sa.Column(sa.DateTime, default=datetime.datetime.utcnow)
     updated_on = sa.Column(
-        sa.DateTime, server_default=sa.func.now(), onupdate=sa.func.current_timestamp()
+        sa.DateTime,
+        server_default=sa.sql.functions.now(),
+        onupdate=sa.sql.functions.current_timestamp(),
     )
 
     project = sa.orm.relationship(
@@ -712,7 +765,7 @@ class ProjectFlag(Base):
     )
 
     def __repr__(self):
-        return "<ProjectFlag(%s, %s, %s)>" % (self.project.name, self.user, self.state)
+        return f"<ProjectFlag({self.project.name}, {self.user}, {self.state})>"
 
     def __json__(self, detailed=False):
         output = dict(
@@ -730,6 +783,7 @@ class ProjectFlag(Base):
 
     @classmethod
     def all(cls, session, page=None, count=False):
+        """all"""
         query = session.query(ProjectFlag).order_by(ProjectFlag.created_on)
 
         return query.all()
@@ -790,11 +844,14 @@ class ProjectFlag(Base):
 
     @classmethod
     def get(cls, session, flag_id):
+        """get"""
         query = session.query(cls).filter(cls.id == flag_id)
         return query.first()
 
 
 class Run(Base):
+    """Class Run"""
+
     __tablename__ = "runs"
 
     total_count = sa.Column(sa.Integer)
@@ -858,10 +915,10 @@ class GUID(TypeDecorator):
             return str(value)
         else:
             if not isinstance(value, uuid.UUID):
-                return "%.32x" % uuid.UUID(value).int
+                return f"{uuid.UUID(value).int:032x}"  # noqa: E231
             else:
                 # hexstring
-                return "%.32x" % value.int
+                return f"{value.int:032x}"  # noqa: E231
 
     def process_result_value(self, value, dialect):
         """
@@ -876,9 +933,34 @@ class GUID(TypeDecorator):
         """
         if value is None:
             return value
+        if isinstance(value, uuid.UUID):
+            return value
         else:
             return uuid.UUID(value)
 
+    def process_literal_param(self, value, dialect):
+        """Receive a literal parameter value to be rendered inline within
+        a statement.
+
+        .. note::
+
+            This method is called during the **SQL compilation** phase of a
+            statement, when rendering a SQL string. Unlike other SQL
+            compilation methods, it is passed a specific Python value to be
+            rendered as a string. However it should not be confused with the
+            :meth:`_types.TypeDecorator.process_bind_param` method, which is
+            the more typical method that processes the actual value passed to a
+            particular parameter at statement execution time.
+
+        Custom subclasses of :class:`_types.TypeDecorator` should override
+        this method to provide custom behaviors for incoming data values
+        that are in the special case of being rendered as literals.
+
+        The returned string will be rendered into the output string.
+
+        """
+        raise NotImplementedError()
+
 
 class User(Base):
     """
@@ -895,8 +977,6 @@ class User(Base):
             able to log in.
         admin (bool): Determine if this user is an administrator. If True the user is
             administrator.
-        social_auth (sqlalchemy.orm.dynamic.AppenderQuery): The list of
-            :class:`social_flask_sqlalchemy.models.UserSocialAuth` entries for this user.
     """
 
     __tablename__ = "users"
@@ -905,7 +985,7 @@ class User(Base):
     # SMTP says 256 is the maximum length of a path:
     # https://tools.ietf.org/html/rfc5321#section-4.5.3
     email = sa.Column(sa.String(256), nullable=False, index=True, unique=True)
-    username = sa.Column(sa.String(256), nullable=False, index=True, unique=True)
+    username = sa.Column(sa.String(256), nullable=False, index=True)
     active = sa.Column(sa.Boolean, default=True)
     admin = sa.Column(sa.Boolean, default=False)
 
@@ -921,6 +1001,8 @@ class User(Base):
         if not self.admin:
             if six.text_type(self.id) in anitya_config.get("ANITYA_WEB_ADMINS", []):
                 self.admin = True
+            if six.text_type(self.email) in anitya_config.get("ANITYA_WEB_ADMINS", []):
+                self.admin = True
         return self.admin
 
     @property
