@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
 """
- (c) 2014-2016 - Copyright Red Hat Inc
+(c) 2014-2016 - Copyright Red Hat Inc
 
- Authors:
-   Pierre-Yves Chibon <pingou@pingoured.fr>
-   Ralph Bean <rbean@redhat.com>
+Authors:
+  Pierre-Yves Chibon <pingou@pingoured.fr>
+  Ralph Bean <rbean@redhat.com>
 
 """
 
@@ -13,7 +13,7 @@ import logging
 
 from defusedxml import ElementTree as ET
 
-from anitya.lib.backends import BaseBackend, get_versions_by_regex, REGEX
+from anitya.lib.backends import REGEX, BaseBackend, get_versions_by_regex
 from anitya.lib.exceptions import AnityaPluginException
 
 _log = logging.getLogger(__name__)
@@ -28,8 +28,8 @@ class CpanBackend(BaseBackend):
 
     name = "CPAN (perl)"
     examples = [
-        "https://metacpan.org/release/Net-Whois-Raw/",
-        "https://metacpan.org/release/SOAP/",
+        "https://metacpan.org/dist/Net-Whois-Raw/",
+        "https://metacpan.org/dist/SOAP/",
     ]
 
     @classmethod
@@ -44,7 +44,7 @@ class CpanBackend(BaseBackend):
         Returns:
             str: url used for version checking
         """
-        url = "https://metacpan.org/release/%(name)s/" % {"name": project.name}
+        url = f"https://metacpan.org/dist/{project.name}/"  # noqa: E231
 
         return url
 
@@ -80,13 +80,13 @@ class CpanBackend(BaseBackend):
 
         try:
             response = cls.call_url(url)
-        except Exception:  # pragma: no cover
-            raise AnityaPluginException("Could not contact %s" % url)
+        except Exception as exc:  # pragma: no cover
+            raise AnityaPluginException(f"Could not contact {url}") from exc
 
         try:
             root = ET.fromstring(response.text)
-        except ET.ParseError:
-            raise AnityaPluginException("No XML returned by %s" % url)
+        except ET.ParseError as exc:
+            raise AnityaPluginException(f"No XML returned by {url}") from exc
 
         for item in root.iter(tag="{http://purl.org/rss/1.0/}item"):
             title = item.find("{http://purl.org/rss/1.0/}title")
@@ -94,5 +94,5 @@ class CpanBackend(BaseBackend):
                 name, version = title.text.rsplit("-", 1)
             except ValueError:
                 _log.info("Unable to parse CPAN package %s into a name and version")
-            homepage = "https://metacpan.org/release/%s/" % name
+            homepage = f"https://metacpan.org/dist/{name}/"  # noqa: E231
             yield name, homepage, cls.name, version
