@@ -1,15 +1,14 @@
 # -*- coding: utf-8 -*-
 
 """
- (c) 2014 - Copyright Red Hat Inc
+(c) 2014 - Copyright Red Hat Inc
 
- Authors:
-   Pierre-Yves Chibon <pingou@pingoured.fr>
+Authors:
+  Pierre-Yves Chibon <pingou@pingoured.fr>
 
 """
 
-from anitya.lib.backends import BaseBackend, get_versions_by_regex, REGEX
-
+from anitya.lib.backends import REGEX, BaseBackend, get_versions_by_regex
 
 REGEX_ALIASES = {"DEFAULT": REGEX}
 
@@ -74,3 +73,21 @@ class CustomBackend(BaseBackend):
             regex = regex % {"name": project.name.replace("+", r"\+")}
 
         return get_versions_by_regex(url, regex, project, insecure=project.insecure)
+
+    @classmethod
+    def check_feed(cls):  # pragma: no cover
+        """Method called to retrieve the latest uploads to a given backend,
+        via, for example, RSS or an API.
+
+        Not Supported
+
+        Returns:
+            :obj:`list`: A list of 4-tuples, containing the project name, homepage, the
+            backend, and the version.
+
+        Raises:
+             NotImplementedError: If backend does not
+                support batch updates.
+
+        """
+        raise NotImplementedError()
