@@ -1,17 +1,18 @@
 # -*- coding: utf-8 -*-
 
 """
- (c) 2014 - Copyright Red Hat Inc
+(c) 2014 - Copyright Red Hat Inc
 
- Authors:
-   Pierre-Yves Chibon <pingou@pingoured.fr>
+Authors:
+  Pierre-Yves Chibon <pingou@pingoured.fr>
 
 """
 
-from anitya.lib.backends import BaseBackend, get_versions_by_regex_for_text, REGEX
-from anitya.lib.exceptions import AnityaPluginException
 import six
 
+from anitya.lib.backends import REGEX, BaseBackend, get_versions_by_regex_for_text
+from anitya.lib.exceptions import AnityaPluginException
+
 DEFAULT_REGEX = 'href="(?:/files/)?([0-9][0-9.]+.*)/"'
 
 
@@ -64,9 +65,8 @@ class FolderBackend(BaseBackend):
             req = cls.call_url(url, last_change=last_change, insecure=project.insecure)
         except Exception as err:
             raise AnityaPluginException(
-                'Could not call : "%s" of "%s", with error: %s'
-                % (url, project.name, str(err))
-            )
+                f'Could not call : "{url}" of "{project.name}", with error: {str(err)}'
+            ) from err
 
         versions = []
 
@@ -84,3 +84,21 @@ class FolderBackend(BaseBackend):
             versions = get_versions_by_regex_for_text(req, url, DEFAULT_REGEX, project)
 
         return versions
+
+    @classmethod
+    def check_feed(cls):  # pragma: no cover
+        """Method called to retrieve the latest uploads to a given backend,
+        via, for example, RSS or an API.
+
+        Not Supported
+
+        Returns:
+            :obj:`list`: A list of 4-tuples, containing the project name, homepage, the
+            backend, and the version.
+
+        Raises:
+             NotImplementedError: If backend does not
+                support batch updates.
+
+        """
+        raise NotImplementedError()
