@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 
 """
- (c) 2014 - Copyright Red Hat Inc
+(c) 2014 - Copyright Red Hat Inc
 
- Authors:
-   Pierre-Yves Chibon <pingou@pingoured.fr>
+Authors:
+  Pierre-Yves Chibon <pingou@pingoured.fr>
 
 """
 
 
-from anitya.lib.backends import BaseBackend, get_versions_by_regex, REGEX
+from anitya.lib.backends import REGEX, BaseBackend, get_versions_by_regex
 
 
 class HackageBackend(BaseBackend):
@@ -37,7 +37,7 @@ class HackageBackend(BaseBackend):
         Returns:
             str: url used for version checking
         """
-        url = "https://hackage.haskell.org/package/%(name)s" % {"name": project.name}
+        url = f"https://hackage.haskell.org/package/{project.name}"  # noqa: E231
 
         return url
 
