@@ -23,12 +23,13 @@ from __future__ import unicode_literals
 
 import functools
 import re
-from typing import Optional
 from datetime import datetime
+from typing import Optional
+
+import packaging.version
 
 from anitya.lib.exceptions import InvalidVersion
 
-
 #: A regular expression to determine if the version string contains a 'v' prefix.
 v_prefix = re.compile(r"v\d.*")
 
@@ -123,13 +124,53 @@ class Version(object):
 
         return version
 
-    def prerelease(self):
+    def prerelease(self) -> bool:
         """
         Check if a version is a pre-release version.
 
         This basic version implementation does not have a concept of
         pre-releases.
         """
+
+        if not self.version:
+            return False
+
+        for pre_release_filter in self.pre_release_filters:
+            if not pre_release_filter:
+                return False
+
+            # special filter mode "odds"
+            #
+            # The following is an attempt to filter versions for packages
+            # that may use odd-numbered versions for development releases.
+            # This mode attempts to use the `packaging` version parsing to
+            # extract a possible release tuple from the provided version
+            # string, which should work for most version schemas. If an odd
+            # value is detected for the target field, the filter will flag. By
+            # default, this mode will target the "minor" field, but this can
+            # be overridden by appending a target index via `!odds:<idx>`. For
+            # example, `!odds:2` will attempt to use the "micro" field. For
+            # cases where the version cannot be parsed due to an unsupported
+            # schema, the filter processing will just ignore/skip the entry.
+            if pre_release_filter.startswith("!odds"):
+                # determine the specific field to use when considering "odd"
+                # releases -- by default, the "minor" (index 1) will be used
+                _, _, raw_target_idx = pre_release_filter.partition(":")
+                try:
+                    target_idx = int(raw_target_idx)
+                except ValueError:
+                    target_idx = 1
+
+                try:
+                    rguess = packaging.version.Version(self.version).release
+                    if 0 <= target_idx < len(rguess):
+                        if rguess[target_idx] % 2 == 1:
+                            return True
+                except packaging.version.InvalidVersion:
+                    continue
+            elif pre_release_filter in self.version:
+                return True
+
         return False
 
     def postrelease(self):
@@ -170,7 +211,9 @@ class Version(object):
             if not isinstance(version, type(self)):
                 version = type(self)(version=version)
             cast_versions.append(version)
-        return all([self.parse() > v.parse() for v in cast_versions])
+        return all(  # pylint: disable=R1729
+            [self.parse() > v.parse() for v in cast_versions]
+        )
 
     def __lt__(self, other):
         """Support < comparison via objects returned from :meth:`parse`"""
