@@ -27,7 +27,6 @@ import re
 
 from .base import Version
 
-
 try:
     from rpm import labelCompare as _compare_rpm_labels
 except ImportError:
@@ -137,7 +136,7 @@ class RpmVersion(Version):
 
         return (match.group(1), match.group(3), match.group(4))
 
-    def prerelease(self):
+    def prerelease(self) -> bool:
         """
         Check if a version is a pre-release version.
 
@@ -147,11 +146,7 @@ class RpmVersion(Version):
         if self.split_rc(self.parse())[1]:
             return True
 
-        for pre_release_filter in self.pre_release_filters:
-            if pre_release_filter and pre_release_filter in self.version:
-                return True
-
-        return False
+        return super().prerelease()
 
     def __eq__(self, other):
         """
@@ -168,10 +163,7 @@ class RpmVersion(Version):
         if result != 0:
             return False
 
-        if rc1 == rc2 and rcn1 == rcn2:
-            return True
-        else:
-            return False
+        return bool(rc1 == rc2 and rcn1 == rcn2)
 
     def __lt__(self, other):
         v1, rc1, rcn1 = self.split_rc(self.parse())
