@@ -30,13 +30,13 @@ getting data from database.
    Michal Konecny <mkonecny@redhat.com>
 """
 
+import json
 import logging
 import os
-import json
 import sys
 
-from anitya.config import config
 from anitya import db
+from anitya.config import config
 
 _log = logging.getLogger("anitya")
 
@@ -53,31 +53,16 @@ def main():
     users = []
 
     if sar_email:
-        _log.debug("Find users by e-mail {}".format(sar_email))
+        _log.debug("Find users by e-mail %s", sar_email)
         users = users + db.User.query.filter_by(email=sar_email).all()
 
     if sar_username:
-        _log.debug("Find users by username {}".format(sar_username))
+        _log.debug("Find users by username %s", sar_username)
         users = users + db.User.query.filter_by(username=sar_username).all()
 
     users_list = []
     for user in users:
         user_dict = user.to_dict()
-        user_social_auths = db.Session.execute(
-            "SELECT provider,extra_data,uid FROM social_auth_usersocialauth WHERE user_id = :val",
-            {"val": str(user.id)},
-        )
-        user_dict["user_social_auths"] = []
-        # This part is working in postgresql, but in tests we are using sqlite
-        # which doesn't know the UUID type
-        for user_social_auth in user_social_auths:  # pragma: no cover
-            user_dict["user_social_auths"].append(
-                {
-                    "provider": user_social_auth["provider"],
-                    "extra_data": user_social_auth["extra_data"],
-                    "uid": user_social_auth["uid"],
-                }
-            )
         users_list.append(user_dict)
 
     json.dump(users_list, sys.stdout)
