@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
-
+"""UI"""
 from math import ceil
 
-from flask_login import login_required, logout_user, current_user
 import flask
+from flask_login import current_user, login_required, logout_user
 from sqlalchemy.exc import SQLAlchemyError
 
+import anitya
 from anitya.config import config as anitya_config
 from anitya.db import Session, models
-from anitya.lib import utilities, exceptions, plugins as anitya_plugins
-import anitya
-
+from anitya.lib import exceptions
+from anitya.lib import plugins as anitya_plugins
+from anitya.lib import utilities
 
 ui_blueprint = flask.Blueprint(
     "anitya_ui", __name__, static_folder="static", template_folder="templates"
@@ -31,6 +32,7 @@ def get_extended_pattern(pattern):
 
 @ui_blueprint.route("/")
 def index():
+    """index"""
     total = models.Project.all(Session, count=True)
     if current_user.is_authenticated and flask.session.get("next_url", ""):
         next_url = flask.session.get("next_url")
@@ -49,7 +51,14 @@ def about():
 @ui_blueprint.route("/login/", methods=("GET", "POST"))
 @ui_blueprint.route("/login", methods=("GET", "POST"))
 def login():
-    flask.session["next_url"] = flask.request.args.get("next", "/")
+    """login"""
+    next_url = flask.request.args.get("next", "/")
+    if not next_url.startswith("/"):
+        next_url = "/"
+
+    flask.session["next_url"] = next_url
+    if anitya_config["DEBUG"]:  # pragma: no cover
+        return flask.render_template("login_debug.html")
     return flask.render_template("login.html")
 
 
@@ -57,6 +66,7 @@ def login():
 @ui_blueprint.route("/logout")
 @login_required
 def logout():
+    """logout"""
     logout_user()
     return flask.redirect("/")
 
@@ -103,7 +113,7 @@ def delete_token(token):
 @ui_blueprint.route("/project/<int:project_id>")
 @ui_blueprint.route("/project/<int:project_id>/")
 def project(project_id):
-
+    """project"""
     project = models.Project.by_id(Session, project_id)
 
     if not project:
@@ -120,7 +130,7 @@ def project(project_id):
 @ui_blueprint.route("/project/<project_name>")
 @ui_blueprint.route("/project/<project_name>/")
 def project_name(project_name):
-
+    """Project name"""
     page = flask.request.args.get("page", 1)
 
     try:
@@ -150,9 +160,9 @@ def project_name(project_name):
 @ui_blueprint.route("/projects")
 @ui_blueprint.route("/projects/")
 def projects():
-
+    """Projects"""
     page = flask.request.args.get("page", 1)
-
+    sort = flask.request.args.get("sort", None)
     try:
         page = int(page)
     except ValueError:
@@ -161,6 +171,9 @@ def projects():
     projects = models.Project.all(Session, page=page)
     projects_count = models.Project.all(Session, count=True)
 
+    if sort:
+        projects = models.Project.sort_projects(projects, sort)
+
     total_page = int(ceil(projects_count / float(50)))
 
     return flask.render_template(
@@ -177,7 +190,7 @@ def projects():
 @ui_blueprint.route("/projects/updates/")
 @ui_blueprint.route("/projects/updates/<status>")
 def projects_updated(status="updated"):
-
+    """Projects updated"""
     page = flask.request.args.get("page", 1)
     name = flask.request.args.get("name", None)
     log = flask.request.args.get("log", None)
@@ -191,8 +204,8 @@ def projects_updated(status="updated"):
 
     if status not in statuses:
         flask.flash(
-            "%s is invalid, you should use one of: %s; using default: "
-            "`updated`" % (status, ", ".join(statuses)),
+            f"{status} is invalid, you should use one of: "
+            f"{', '.join(statuses)}; using default: `updated`",  # noqa: E702
             "errors",
         )
         flask.flash(
@@ -225,7 +238,7 @@ def projects_updated(status="updated"):
 @ui_blueprint.route("/logs")
 @login_required
 def browse_logs():
-
+    """Browse logs"""
     refresh = flask.request.args.get("refresh", False)
     page = flask.request.args.get("page", 1)
 
@@ -234,8 +247,7 @@ def browse_logs():
     except ValueError:
         page = 1
 
-    if page < 1:
-        page = 1
+    page = max(page, 1)
 
     page_obj = models.Project.query.paginate(
         page=page, order_by=models.Project.last_check.desc()
@@ -260,7 +272,7 @@ def browse_logs():
 @ui_blueprint.route("/distros")
 @ui_blueprint.route("/distros/")
 def distros():
-
+    """distros"""
     page = flask.request.args.get("page", 1)
 
     try:
@@ -286,7 +298,7 @@ def distros():
 @ui_blueprint.route("/distro/<distroname>")
 @ui_blueprint.route("/distro/<distroname>/")
 def distro(distroname):
-
+    """distro"""
     page = flask.request.args.get("page", 1)
 
     try:
@@ -313,7 +325,7 @@ def distro(distroname):
 @ui_blueprint.route("/distro/add", methods=["GET", "POST"])
 @login_required
 def add_distro():
-
+    """add distro"""
     form = anitya.forms.DistroForm()
 
     if form.validate_on_submit():
@@ -345,9 +357,10 @@ def add_distro():
 @ui_blueprint.route("/projects/search/")
 @ui_blueprint.route("/projects/search/<pattern>")
 def projects_search(pattern=None):
-
+    """Search projects"""
     pattern = flask.request.args.get("pattern", pattern) or "*"
     page = flask.request.args.get("page", 1)
+    sort = flask.request.args.get("sort", "name_asc")
     exact = flask.request.args.get("exact", 0)
 
     try:
@@ -357,7 +370,7 @@ def projects_search(pattern=None):
 
     projects = models.Project.search(Session, pattern=pattern, page=page)
 
-    if not str(exact).lower() in ["1", "true"]:
+    if str(exact).lower() not in ["1", "true"]:
         # Extends the search
         for proj in models.Project.search(
             Session, pattern=get_extended_pattern(pattern), page=page
@@ -376,6 +389,8 @@ def projects_search(pattern=None):
             flask.url_for("anitya_ui.project", project_id=projects[0].id)
         )
 
+    projects = models.Project.sort_projects(projects, sort)
+
     total_page = int(ceil(projects_count / float(50)))
 
     return flask.render_template(
@@ -386,6 +401,7 @@ def projects_search(pattern=None):
         total_page=total_page,
         projects_count=projects_count,
         page=page,
+        sort=sort,
     )
 
 
@@ -393,7 +409,7 @@ def projects_search(pattern=None):
 @ui_blueprint.route("/distro/<distroname>/search/")
 @ui_blueprint.route("/distro/<distroname>/search/<pattern>")
 def distro_projects_search(distroname, pattern=None):
-
+    """Search distro projects"""
     pattern = flask.request.args.get("pattern", pattern) or "*"
     page = flask.request.args.get("page", 1)
     exact = flask.request.args.get("exact", 0)
@@ -407,7 +423,7 @@ def distro_projects_search(distroname, pattern=None):
         Session, pattern=pattern, distro=distroname, page=page
     )
 
-    if not str(exact).lower() in ["1", "true"]:
+    if str(exact).lower() not in ["1", "true"]:
         # Extends the search
         for proj in models.Project.search(
             Session, pattern=get_extended_pattern(pattern), distro=distroname, page=page
@@ -492,18 +508,24 @@ def new_project():
                 homepage=form.homepage.data.strip(),
                 backend=form.backend.data.strip(),
                 version_scheme=form.version_scheme.data.strip(),
-                version_url=form.version_url.data.strip()
-                if form.version_url.data
-                else None,
-                version_prefix=form.version_prefix.data.strip()
-                if form.version_prefix.data
-                else None,
-                pre_release_filter=form.pre_release_filter.data.strip()
-                if form.pre_release_filter.data
-                else None,
-                version_filter=form.version_filter.data.strip()
-                if form.version_filter.data
-                else None,
+                version_url=(
+                    form.version_url.data.strip() if form.version_url.data else None
+                ),
+                version_prefix=(
+                    form.version_prefix.data.strip()
+                    if form.version_prefix.data
+                    else None
+                ),
+                pre_release_filter=(
+                    form.pre_release_filter.data.strip()
+                    if form.pre_release_filter.data
+                    else None
+                ),
+                version_filter=(
+                    form.version_filter.data.strip()
+                    if form.version_filter.data
+                    else None
+                ),
                 regex=form.regex.data.strip() if form.regex.data else None,
                 user_id=flask.g.user.username,
                 releases_only=form.releases_only.data,
@@ -558,7 +580,7 @@ def new_project():
 @ui_blueprint.route("/project/<project_id>/edit", methods=["GET", "POST"])
 @login_required
 def edit_project(project_id):
-
+    """Edit project"""
     project = models.Project.get(Session, project_id)
     if not project:
         flask.abort(404)
@@ -584,24 +606,34 @@ def edit_project(project_id):
                 name=form.name.data.strip(),
                 homepage=form.homepage.data.strip(),
                 backend=form.backend.data.strip(),
-                version_scheme=form.version_scheme.data.strip()
-                if form.version_scheme.data
-                else None,
-                version_pattern=form.version_pattern.data.strip()
-                if form.version_pattern.data
-                else None,
-                version_url=form.version_url.data.strip()
-                if form.version_url.data
-                else None,
-                version_prefix=form.version_prefix.data.strip()
-                if form.version_prefix.data
-                else None,
-                pre_release_filter=form.pre_release_filter.data.strip()
-                if form.pre_release_filter.data
-                else None,
-                version_filter=form.version_filter.data.strip()
-                if form.version_filter.data
-                else None,
+                version_scheme=(
+                    form.version_scheme.data.strip()
+                    if form.version_scheme.data
+                    else None
+                ),
+                version_pattern=(
+                    form.version_pattern.data.strip()
+                    if form.version_pattern.data
+                    else None
+                ),
+                version_url=(
+                    form.version_url.data.strip() if form.version_url.data else None
+                ),
+                version_prefix=(
+                    form.version_prefix.data.strip()
+                    if form.version_prefix.data
+                    else None
+                ),
+                pre_release_filter=(
+                    form.pre_release_filter.data.strip()
+                    if form.pre_release_filter.data
+                    else None
+                ),
+                version_filter=(
+                    form.version_filter.data.strip()
+                    if form.version_filter.data
+                    else None
+                ),
                 regex=form.regex.data.strip() if form.regex.data else None,
                 insecure=form.insecure.data,
                 user_id=flask.g.user.username,
@@ -631,7 +663,7 @@ def edit_project(project_id):
 @ui_blueprint.route("/project/<project_id>/flag", methods=["GET", "POST"])
 @login_required
 def flag_project(project_id):
-
+    """Flag project"""
     project = models.Project.get(Session, project_id)
     if not project:
         flask.abort(404)
@@ -665,7 +697,7 @@ def flag_project(project_id):
 @ui_blueprint.route("/project/<project_id>/map", methods=["GET", "POST"])
 @login_required
 def map_project(project_id):
-
+    """Map project"""
     project = models.Project.get(Session, project_id)
     if not project:
         flask.abort(404)
@@ -709,7 +741,7 @@ def map_project(project_id):
 @ui_blueprint.route("/project/<project_id>/map/<pkg_id>", methods=["GET", "POST"])
 @login_required
 def edit_project_mapping(project_id, pkg_id):
-
+    """Edit project mapping"""
     project = models.Project.get(Session, project_id)
     if not project:
         flask.abort(404)
@@ -731,7 +763,6 @@ def edit_project_mapping(project_id, pkg_id):
     )
 
     if form.validate_on_submit():
-
         try:
             utilities.map_project(
                 Session,
@@ -765,7 +796,7 @@ def format_examples(examples):
         for cnt, example in enumerate(examples):
             if cnt > 0:
                 output += " <br /> "
-            output += "<a href='%(url)s'>%(url)s</a> " % ({"url": example})
+            output += f"<a href='{example}'>{example}</a> "
 
     return output
 
